FileHelper class

Constructors

FileHelper({required ProcessHelper processHelper})

Properties

hashCode → int
The hash code for this object.
no setterinherited
processHelper → ProcessHelper
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy(Directory source, Directory destination, {ShouldCopy? shouldCopy, PostCopy? postCopy}) → Future<void>
createTemporaryDirectory() → Future<Directory>
makeExecutable(File file) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit(Directory directory, FileSystemEntityVisitor visitor) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited