GitHelper class

Constructors

GitHelper({required ProcessHelper processHelper, required FileHelper fileHelper})

Properties

fileHelper → FileHelper
final
gitDirectoryRoot → Future<Directory>
no setter
hashCode → int
The hash code for this object.
no setterinherited
processHelper → ProcessHelper
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cloneRepository(String gitUrl, String? ref, Directory cloneDir) → Future<void>
executePostInstall(Directory directory) → Future<void>
executePreUninstall(Directory directory) → Future<void>
getLocalHooksDirectory() → Future<Directory>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCoreHooksPath(Directory directory) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

kHooksSignature → const Set<String>
Set of supported Git hooks
postInstall → const String
preUninstall → const String