RemoteHooksConfig class

Constructors

RemoteHooksConfig({String? gitUrl, List<String> filePaths = const [], required FileHelper fileHelper})

Properties

fileHelper → FileHelper
final
filePaths ↔ List<String>
getter/setter pair
gitUrl ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanUpFiles(Directory directory) → Future<void>
loadConfig({required Directory directory}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
writeConfig({required Directory directory}) → Future<File>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

kRemoteHooksConfig → const String