YamlConfig class

Constructors

YamlConfig({String? gitUrl, String? ref, required GitHelper gitHelper})

Properties

gitHelper → GitHelper
final
gitUrl ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ref ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

load({required Directory directory}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

gitUrlKey → const String
refKey → const String
yamlFileName → const String